function varargout = mhf_controller( flag, varargin)  % TEXFEM

global mhf_controller_P;      % the prior local peak values
global mhf_controller_sgn_d;  % the previous sign of the velocity

% Copyright (C) 2001 Matthew W. Roberts
% Released under the GNU Public License (See end of file for details.)

% varargin{1} = data structure
% varargin{2} = sensor output (controller input)

switch flag
	case 'controller-init'
		mhf_controller_P( varargin{1}.num) = 0;
		mhf_controller_sgn_d( varargin{1}.num) = 0;
	case 'controller-force'
		% d = varargin{1};
		% s = varargin{2};   
		varargout{1} = local_force( varargin{1}, varargin{2}, 1);
	case 'controller-force-iterate'
		varargout{1} = local_force( varargin{1}, varargin{2}, 0);
	otherwise
		warning(['disp_sensor: Unknown option ''' flag '''.']);
end

function f = local_force( d, s, update_P)

	global mhf_controller_P;
	global mhf_controller_sgn_d;

	f =  zeros( 2,2);

	node_index = d.direction;

	% Determine the force direction -- s.output(:,2) = velocity;
	vel = s(2).output(node_index,2) - s(1).output(node_index,2);
	dir = - sign( vel);

	if d.passive % {
		if abs(vel) < d.min_velocity
			% Force vs. Velocity is dropping off linearly here
			f(node_index,1) = - vel * d.max_force / d.min_velocity;
		else
			f(node_index,1) = dir * d.max_force;
		end
	else % } {
		% Change the prior local peak operator, if necessary
		if update_P
			if abs(dir) < eps
				% Hit a peak, update P
				mhf_controller_P(d.num) = abs( s(1).output(node_index,1) - ...
					s(2).output(node_index,1));
				mhf_controller_sgn_d( d.num) = 0;
				% disp(sprintf( 'MHF: dir ==0 (%f %f: %f)', s(2).output(node_index,2), ...
					% s(1).output(node_index,2), mhf_controller_P(d.num)));
			elseif mhf_controller_sgn_d(d.num) == 0
				% We're off the peak now
				mhf_controller_sgn_d(d.num) = dir;
			elseif mhf_controller_sgn_d(d.num) ~= 0 & mhf_controller_sgn_d(d.num) ~= dir
				% Velocity changed sign.  There must have been a peak before.
				% Go ahead and assume the peak occured now.
				mhf_controller_P(d.num) = abs(s(1).output(node_index,1) - ...
					s(2).output(node_index,1));
				mhf_controller_sgn_d(d.num) = dir;
				% disp(sprintf( 'MHF: Changed sign (%f)', mhf_controller_P(d.num)));
			end
		end % if update_P
		% now, apply the force
		if abs(vel) < d.min_velocity
			% Force vs. Velocity is dropping off linearly here
			f(node_index,1) = - d.g * vel * mhf_controller_P(d.num) / d.min_velocity;
		else
			f(node_index,1) = dir * d.g * mhf_controller_P(d.num);
		end
		% Check saturation
		if abs(f(node_index,1)) > d.max_force
			% TODO:  this needs to handle the case where the velocity is below the min.
			f(node_index,1) = dir * d.max_force;
		end
	end % }
	f(node_index,2) = - f(node_index,1);   % equal and opposite

% --------------------------------------------------------------------------

% {TEX} A controller based on the Modulated Homogeneous Friction algorithm
% {TEX} \cite(inaudi97a}.

% Licence Details

% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.

% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.

% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
