function  varargout = elget (n, data, what, varargin)
%
% SYNOPSIS
%
% varargout = elget (n, data, what)
%
% Makes it easier to get information about an element.
% n is the element number, data is the global data structure, what
% is a string specifying what you want

type  = data.elements(n).type;
el    = data.elements(n);
mat   = data.materials(data.elements(n).material);
sec   = data.sections(data.elements(n).section);

switch what
	case {'stiffness-matrix','pre-yield-stiffness-matrix','nonlinear-data','damping-matrix'}
		varargout{1} = feval( type, what, el, mat, sec, data.nodelist);
	case 'transformation-matrix'
		varargout{1} = feval( type, what, el, data.nodelist);
	case 'element-stress'
		if isfield( data, 'disp')
			trans_vec = dofvec( el, data.num_dofs, data.dofs_pos);
			varargout{1} = feval( type, what, el, mat, sec, ...
				data.nodelist, data.disp(trans_vec))';
		end
	case 'nonlinear-global-force'
		[varargout{1} varargout{2} varargout{3}] = feval( type, what, el, mat, sec, data.nodelist, varargin{:});
	otherwise
		error(['elget: Unknown option ''' what '''.']);
end

%  GNUFEM -- A free finite element code for Matlab
%
% Licence Details and Credits:
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
%
% Adapted from the FElt Finite Element package by Jason I. Gobat
% and Darren C. Atkinson 
