function varargout = trussutil( flag, varargin)

% SYNOPSIS:
%
% varargout = trussutil( flag, ...)
%
% Builds a two-dimensional beam stiffness matrix (4x4).
%
%   K_truss = trussutil('stiffness-matrix', A, E, L)
%     Builds a three-dimensional truss stiffness matrix.  A, E, and L are the
%     member cross- sectional area, young's modulus, and length, respectively.
%
%   T_truss = trussutil('transformation-matrix', node1, node2)
%     Builds a three-dimensional truss transformation matrix.  node1 and node2
%     are the coordinates of the nodes at the ends of the element.  [x y z]

% Copyright (C) 2001 Matthew W. Roberts
% Released under the GNU Public License (See end of file for details.)

switch flag
	case 'stiffness-matrix'  % `y' refers to Theta_y, which means x-z bending
		K = local_linear_K( varargin);
	case 'transformation-matrix'
		K = local_transformation( varargin);
end

function  a = local_linear_K( A, E, L)

% i = sqrt(-1), I'll use ii and jj
ii = [];   % set up the sparse matrices

% Licence Details and Credits:

% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.

% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.

% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

% Adapted from the FElt Finite Element package by Jason I. Gobat
% and Darren C. Atkinson 
