function  [Rc,dof_map] = apply_bc ( R, data, flag)
%
% SYNOPSIS
%
% [Rc,dof_map] = implement_bc ( R, data, flag)
%
% Implements the boundary conditions.  Behavior is
% based on the `flag' argument:
%
% flag = 'zero'
%   Simply zero out the rows and columns of fixed dofs placing
%   a 1 on the diagonal.  This is the default since it is the
%   easiest.
%
% flag = 'remove'
%   Remove entirely the rows and columns corresponding to fixed dofs.
%
% Hinges and fixed displacement boundary conditions not considered at
% this time.

total_dof = data.num_nodes * data.num_dofs;

if nargin < 3
	flag = 'zero';
end

if strcmp( flag, 'remove')
	zero = 0;
	keep = ones( 1,total_dof);      % assume all are kept initially
else
	dof_map = 1 : total_dof;  % doesn't change
	Rc = R;
	zero = 1;
end

for i = 1 : data.num_nodes

	base_dof = data.num_dofs * (i - 1);

	for j = 1 : data.num_dofs

		if data.boundary_conditions( i, j) > 0

			if zero
				Rc ( base_dof + j, 1 : total_dof) = zeros( 1, total_dof); 
				Rc ( 1 : total_dof, base_dof + j) = zeros( total_dof, 1); 
				Rc ( base_dof + j, base_dof + j) = 1;
			else
				keep( base_dof + j) = 0;
			end
		end % if data.boundary_condtions...
	end % for j
end % for i

if ~ zero
	dof_map = find(keep);
	Rc = R (dof_map, dof_map);
end


%  GNUFEM -- A free finite element code for Matlab
%
% Licence Details and Credits:
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
%
% Adapted from the FElt Finite Element package by Jason I. Gobat
% and Darren C. Atkinson 
