function  C = c_modal ( M, K, xi)
%
% SYNOPSIS
%
% function  C = c_modal ( M, K, xi)
%
% Creates a C matrix based on modal damping values.
%
%  Input
%
%  M  - Mass Matrix, assumed to be diagonal.
%  K  - Stiffness matrix.
%  xi - Vector of xi values, the percentage of critical damping for
%       each mode.  xi(1) for fundamental mode, etc.

[vecs, vals] = difeig( M, K);

Cmodal = zeros(size(M));

if size(xi,2) > size(xi,1)
	% must be a row vector
	xi = xi';
end

if length(xi) < size(M,1)
	% The commented code directly following seems to assume that
	% vecs' * M * vecs = M
	% That may only be the case for one-dimensional structures
	% for x = 1:size(M,1)
		% Cmodal(x,x) = 2 * xi(1) * M(x,x) * sqrt( vals(x));
	% end
	Cmodal = diag(2 * xi(1) * ( sqrt(vals) .* diag( vecs' * M * vecs)));
else
	Cmodal = diag(2 * xi .* ( sqrt(vals) .* diag( vecs' * M * vecs)));
	%for x = 1:size(M,1)
		%Cmodal(x,x) = 2 * xi(x) * M(x,x) * sqrt( vals(x));
	%end
end

% Transform back from modal space
C = inv(vecs') * Cmodal * inv(vecs);

%  GNUFEM -- A free finite element code for Matlab
%
% Licence Details and Credits:
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
%
% Adapted from the FElt Finite Element package by Jason I. Gobat
% and Darren C. Atkinson 
