function nodal = combine2nodal( a, T, nodes)
% 
% Synopsis:
% nodal = combine2nodal( a, T, nodes)
%
% returns a matrix (`nodal') of nodal displacements based on the displacement
% matrix `a' which was generated using the combine function with nodal
% definition matrix `nodes'.
%
% T is the transformation from rigid floor coordinate (x,y,theta) to 
% nodal coordinates (x1, y1, theta1)

% 3 * numstory x 3 * numstory

% mapvec maps the rigid floor entries to the correct nodal entries
mapvec = zeros(1,3*size(nodes,1));

for i = 1:size(nodes,1)
	mapvec((i-1)*3+1:(i-1)*3+3) = (nodes(i,3)-1)*3+1:(nodes(i,3)-1)*3+3;
end

for i = 1 : size(a,1)
	nodal(i,:) = (T * a(i,mapvec)')';
end


%  GNUFEM -- A free finite element code for Matlab
%
% Licence Details and Credits:
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
%
% Adapted from the FElt Finite Element package by Jason I. Gobat
% and Darren C. Atkinson 
