function  Rc = constrain ( R, data, flag)
%
% SYNOPSIS
%
% Rc = constrain ( R, data, flag)
%
% Implements the boundary conditions.  Behavior is
% based on the `flag' argument:
%
% flag = 'zero'
%   Simply zero out the rows and columns of fixed dofs placing
%   a 1 on the diagonal.  This is the default since it is the
%   easiest.
%
% flag = 'remove'
%   Remove entirely the rows and columns corresponding to fixed dofs.
%
% Hinges and fixed displacement boundary conditions not considered at
% this time.

total_dof = data.num_nodes * data.num_dofs;

if nargin < 3
	flag = 'zero';
end

if strcmp( flag, 'remove')
	zero = 0;
	keep = ones( 1,total_dof);   % assume all are kept initially
else
	Rc = R;
	zero = 1;
end

for i = 1 : data.num_nodes

	base_dof = data.num_dofs * (i - 1);

	for j = 1 : data.num_dofs

		if data.boundary_conditions( i, j) > 0

			if zero
				Rc ( base_dof + j, 1 : total_dof) = zeros( 1, total_dof); 
				Rc ( 1 : total_dof, base_dof + j) = zeros( total_dof, 1); 
				Rc ( base_dof + j, base_dof + j) = 1;
			else
				keep( base_dof + j) = 0;
			end
		end % if data.boundary_condtions...
	end % for j
end % for i

if ~ zero
	Rc = R (find(keep), find(keep));
end
