function [Knew,T] = constrain3dslab2n( K, data, dof_map)
% 
% Synopsis:
% [Kconst,T] = constrain3dslab2n( k, data, dof_map)
%
% Builds a new K matrix such that KD = F, where K is the stiffness
% matrix of the constrained system, D is the vector of slab 
% displacements: [ ... X_i, Y_i, \Theta_i ... ], and F is the vector of
% forces applied to the mass centroid of the slab:
% [ ... F_xi F_yi M_i ... ].
%
% This routine assumes that K has already been condensed to a 2n x 2n
% matrix (`n' being the number of nodes) 
%
% T is the transformation matrix such that d = TD where d are the nodal
% displacements (x- and y- directions).
%
% `data' is a finite element data structure.
%
% `m' is assumed to be lumped mass with all mass on the diagonal.
%
% dof_map shows which degrees of freedom are contained in K

% Copyright (C) 2001 Matthew W. Roberts
% Released under the GNU Public License (See end of file for details.)

% Build the Transformation matrix such that d = T D
% where d are the nodal coordinates and D are the "slab" coordinates

% t is used to store the transformation d_i = t D_k where d_i = [x_i y_i]'
% and D_k = [ X_k Y_k \Theta_k]' for story k  (node i is part of story k)
t = [ eye(2) , zeros(2,1)];
T = zeros(size(K,1), length(data.constraints));

for x = 1 : length(data.constraints)  % floor number
	for y = 1 : length( data.constraints(x).nodes)
		node = data.constraints(x).nodes(y);
		t(1,3) = - ( data.nodelist(node,2) - data.center_of_mass(x,2));
		t(2,3) =   ( data.nodelist(node,1) - data.center_of_mass(x,1));
		T_row = find( dof_map == (node*6 - 5));
		T_col = x*3 - 2;
		T(T_row:T_row+1,T_col:T_col+2) = t;
	end
end

Knew = T' * K * T;

% LICENCE DETAILS
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.

% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.

% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
