function v = dofvec( element, num_dofs, dofs_pos)
% 
% Synopsis:
% v = dofvec( element, num_dofs, dofs_pos)
%
% element  - FEM element for which to build the dof vector.
% num_dofs - Number of degrees of freedom in the global matrix.
% dofs_pos - Vector mapping the global DOFs, see findDOFs for details.
%
% builds the degree-of-freedom vector which maps from the local
% (element) nodes to the global nodes.

ndofs  = feval( element.type, 'num-dof');
nnodes = feval( element.type, 'num-nodes');

% the degree of freedom vector for the element
element_dof_vec = feval( element.type, 'dof-vector');

% build the transformation vector to the global stiffness matrix
v = zeros( 1, nnodes*ndofs);
pos = 1;  % current position in the transformation vector
for j = 1 : nnodes
	if element.nodes(j) > 0
		% The starting row/col for this node, (minus 1)
		base = (element.nodes(j) - 1) * num_dofs;

		for k = 1 : ndofs
			% add the offset for this degree of freedom
			v(pos) = base + dofs_pos(element_dof_vec(k));
			pos = pos + 1;
		end  % for k
	end  % if element...
end  % for j

%  GNUFEM -- A free finite element code for Matlab
%
% Licence Details and Credits:
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
%
% Adapted from the FElt Finite Element package by Jason I. Gobat
% and Darren C. Atkinson 
