function  elements = element_struct ( element_matrix)
%
% SYNOPSIS
%
% elements = element_struct ( element_matrix)
%
% Creates the necessary array of element structures from element_matrix.
% element_matrix is an n x (p+2) matrix with n being the number of elements and
% p being the maximum number of nodes per element.
%
% Each row of element_matrix is of the form:
%
% [ M S n1 n2 ... ]
%
% Where M is the element material number, S is the section number, and
% [ n1 n2 ... ] are the node numbers which are part of the element
% In the case where some elements have more nodes than others, the "extra" node
% numbers should be zero.

p = size( element_matrix, 2);

for n = 1 : size(element_matrix, 1)
	elements(n).material = element_matrix( n, 1);
	elements(n).section  = element_matrix( n, 2);
	elements(n).nodes    = element_matrix( n, 2 + find( element_matrix(n,3:p)));
end

%  GNUFEM -- A free finite element code for Matlab
%
% Licence Details and Credits:
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
%
% Adapted from the FElt Finite Element package by Jason I. Gobat
% and Darren C. Atkinson 
