function  f = load_vector ( load_matrix, data)
%
% SYNOPSIS
%
% f = load_vector ( load_matrix, data)
%
% Creates f:  the load vector (right hand side) for a problem.
%
% load_matrix is an n x 3 matrix where n is the number of point loads.
% The rows of load_matrix are: [N mag dir], where N is the node number,
% mag is the magnitude of the force, and dir is the direction.  The
% direction is given as one of the 6 possible degrees of freedom:\
% 1 = x-force,  2 = y-force,  3 = z-force
% 4 = x-moment, 5 = y-moment, 6 = z-moment

f = zeros( data.num_nodes * data.num_dofs, 1);

for n = 1 : size(load_matrix, 1)
	
	offset = find( data.dofs_num == load_matrix( n, 3));
	if load_matrix( n, 3) > 0 & length( offset) == 1
		row = offset + data.num_dofs * (load_matrix(n,1) - 1);
		f(row) = f(row) + load_matrix( n, 2);
	else
		warning( ['Invalid direction for nodal load: ' num2str(load_matrix( n, 3)) ]);
	end
end

%  GNUFEM -- A free finite element code for Matlab
%
% Licence Details and Credits:
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
%
% Adapted from the FElt Finite Element package by Jason I. Gobat
% and Darren C. Atkinson 
