function [mv,mlv] = massbc( bc, massvec, masslessvec)
%
% Synopsis:
%
% [mv,mlv] = massbc( bc, massvec, masslessvec)
%
% Adjusts massvec and masslessvec (e.g. from condense) to account
% for fixed degrees of freedom that were removed from the system.
%
% This function is usually needed to find the "absolute" degrees
% of freedom for a mass vector when condense is called after 
% apply_bc( ..., 'remove')
%
% bc is a n x m boundary condition matrix as used in the data 
% structure where n is the number of nodes, m is dofs per node

fixed_bc = find(bc');

%  Degrees of freedom are 1 through n for first node,
%  n+1 throught 2n for second, ...
%  where n is the number of degrees of freedom per node
curdof  = 1;  % the current absolute degree of freedom
massdof = 1;  % the current dof in mass[less]vec

% Return values
mv  = massvec;
mlv = masslessvec;

% Find and remap any missing degrees of freedom
for x = fixed_bc';
	while x ~= curdof
		k = find(mv >= massdof);
		mv(k) = mv(k) + curdof - massdof;
		k = find(mlv >= massdof);
		mlv(k) = mlv(k) + curdof - massdof;
		curdof = curdof + 1;
		massdof = curdof;
	end
	curdof = curdof + 1;
end

% Now, take care of dofs after the end of fixed_bc
k = find(mv >= massdof);
mv(k) = mv(k) + curdof - massdof;
k = find(mlv >= massdof);
mlv(k) = mlv(k) + curdof - massdof;

%  GNUFEM -- A free finite element code for Matlab
%
% Licence Details and Credits:
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
%
% Adapted from the FElt Finite Element package by Jason I. Gobat
% and Darren C. Atkinson 
